"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AuthClientController = void 0;
const tslib_1 = require("tslib");
const repository_1 = require("@loopback/repository");
const rest_1 = require("@loopback/rest");
const models_1 = require("../models");
const repositories_1 = require("../repositories");
const loopback4_authorization_1 = require("loopback4-authorization");
const loopback4_authentication_1 = require("loopback4-authentication");
const core_1 = require("@sourceloop/core");
const baseUrl = '/auth-clients';
let AuthClientController = class AuthClientController {
    constructor(authClientRepository) {
        this.authClientRepository = authClientRepository;
    }
    async create(authClient) {
        return this.authClientRepository.create(authClient);
    }
    async count(where) {
        return this.authClientRepository.count(where);
    }
    async find(filter) {
        return this.authClientRepository.find(filter);
    }
    async updateAll(authClient, where) {
        return this.authClientRepository.updateAll(authClient, where);
    }
    async findById(id) {
        return this.authClientRepository.findById(id);
    }
    async updateById(id, authClient) {
        await this.authClientRepository.updateById(id, authClient);
    }
    async replaceById(id, authClient) {
        await this.authClientRepository.replaceById(id, authClient);
    }
    async deleteById(id) {
        await this.authClientRepository.deleteById(id);
    }
};
(0, tslib_1.__decorate)([
    (0, loopback4_authentication_1.authenticate)("bearer" /* BEARER */),
    (0, loopback4_authorization_1.authorize)({ permissions: ["NotAllowed" /* NotAllowed */] }),
    (0, rest_1.post)(baseUrl, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [200 /* OK */]: {
                description: 'AuthClient model instance',
                content: { [core_1.CONTENT_TYPE.JSON]: { schema: (0, rest_1.getModelSchemaRef)(models_1.AuthClient) } },
            },
        },
    }),
    (0, tslib_1.__param)(0, (0, rest_1.requestBody)({
        content: {
            [core_1.CONTENT_TYPE.JSON]: {
                schema: (0, rest_1.getModelSchemaRef)(models_1.AuthClient, { exclude: ['id'] }),
            },
        },
    })),
    (0, tslib_1.__metadata)("design:type", Function),
    (0, tslib_1.__metadata)("design:paramtypes", [Object]),
    (0, tslib_1.__metadata)("design:returntype", Promise)
], AuthClientController.prototype, "create", null);
(0, tslib_1.__decorate)([
    (0, loopback4_authentication_1.authenticate)("bearer" /* BEARER */),
    (0, loopback4_authorization_1.authorize)({ permissions: ["NotAllowed" /* NotAllowed */] }),
    (0, rest_1.get)(`${baseUrl}/count`, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [200 /* OK */]: {
                description: 'AuthClient model count',
                content: { [core_1.CONTENT_TYPE.JSON]: { schema: repository_1.CountSchema } },
            },
        },
    }),
    (0, tslib_1.__param)(0, rest_1.param.query.object('where', (0, rest_1.getWhereSchemaFor)(models_1.AuthClient))),
    (0, tslib_1.__metadata)("design:type", Function),
    (0, tslib_1.__metadata)("design:paramtypes", [Object]),
    (0, tslib_1.__metadata)("design:returntype", Promise)
], AuthClientController.prototype, "count", null);
(0, tslib_1.__decorate)([
    (0, loopback4_authentication_1.authenticate)("bearer" /* BEARER */),
    (0, loopback4_authorization_1.authorize)({ permissions: ["NotAllowed" /* NotAllowed */] }),
    (0, rest_1.get)(baseUrl, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [200 /* OK */]: {
                description: 'Array of AuthClient model instances',
                content: {
                    [core_1.CONTENT_TYPE.JSON]: {
                        schema: { type: 'array', items: (0, rest_1.getModelSchemaRef)(models_1.AuthClient) },
                    },
                },
            },
        },
    }),
    (0, tslib_1.__param)(0, rest_1.param.query.object('filter', (0, rest_1.getFilterSchemaFor)(models_1.AuthClient))),
    (0, tslib_1.__metadata)("design:type", Function),
    (0, tslib_1.__metadata)("design:paramtypes", [Object]),
    (0, tslib_1.__metadata)("design:returntype", Promise)
], AuthClientController.prototype, "find", null);
(0, tslib_1.__decorate)([
    (0, loopback4_authentication_1.authenticate)("bearer" /* BEARER */),
    (0, loopback4_authorization_1.authorize)({ permissions: ["NotAllowed" /* NotAllowed */] }),
    (0, rest_1.patch)(baseUrl, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [200 /* OK */]: {
                description: 'AuthClient PATCH success count',
                content: { [core_1.CONTENT_TYPE.JSON]: { schema: repository_1.CountSchema } },
            },
        },
    }),
    (0, tslib_1.__param)(0, (0, rest_1.requestBody)({
        content: {
            [core_1.CONTENT_TYPE.JSON]: {
                schema: (0, rest_1.getModelSchemaRef)(models_1.AuthClient, { partial: true }),
            },
        },
    })),
    (0, tslib_1.__param)(1, rest_1.param.query.object('where', (0, rest_1.getWhereSchemaFor)(models_1.AuthClient))),
    (0, tslib_1.__metadata)("design:type", Function),
    (0, tslib_1.__metadata)("design:paramtypes", [models_1.AuthClient, Object]),
    (0, tslib_1.__metadata)("design:returntype", Promise)
], AuthClientController.prototype, "updateAll", null);
(0, tslib_1.__decorate)([
    (0, loopback4_authentication_1.authenticate)("bearer" /* BEARER */),
    (0, loopback4_authorization_1.authorize)({ permissions: ["NotAllowed" /* NotAllowed */] }),
    (0, rest_1.get)(`${baseUrl}/{id}`, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [200 /* OK */]: {
                description: 'AuthClient model instance',
                content: { [core_1.CONTENT_TYPE.JSON]: { schema: (0, rest_1.getModelSchemaRef)(models_1.AuthClient) } },
            },
        },
    }),
    (0, tslib_1.__param)(0, rest_1.param.path.number('id')),
    (0, tslib_1.__metadata)("design:type", Function),
    (0, tslib_1.__metadata)("design:paramtypes", [Number]),
    (0, tslib_1.__metadata)("design:returntype", Promise)
], AuthClientController.prototype, "findById", null);
(0, tslib_1.__decorate)([
    (0, loopback4_authentication_1.authenticate)("bearer" /* BEARER */),
    (0, loopback4_authorization_1.authorize)({ permissions: ["NotAllowed" /* NotAllowed */] }),
    (0, rest_1.patch)(`${baseUrl}/{id}`, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            '204': {
                description: 'AuthClient PATCH success',
            },
        },
    }),
    (0, tslib_1.__param)(0, rest_1.param.path.number('id')),
    (0, tslib_1.__param)(1, (0, rest_1.requestBody)({
        content: {
            [core_1.CONTENT_TYPE.JSON]: {
                schema: (0, rest_1.getModelSchemaRef)(models_1.AuthClient, { partial: true }),
            },
        },
    })),
    (0, tslib_1.__metadata)("design:type", Function),
    (0, tslib_1.__metadata)("design:paramtypes", [Number, models_1.AuthClient]),
    (0, tslib_1.__metadata)("design:returntype", Promise)
], AuthClientController.prototype, "updateById", null);
(0, tslib_1.__decorate)([
    (0, loopback4_authentication_1.authenticate)("bearer" /* BEARER */),
    (0, loopback4_authorization_1.authorize)({ permissions: ["NotAllowed" /* NotAllowed */] }),
    (0, rest_1.put)(`${baseUrl}/{id}`, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            '204': {
                description: 'AuthClient PUT success',
            },
        },
    }),
    (0, tslib_1.__param)(0, rest_1.param.path.number('id')),
    (0, tslib_1.__param)(1, (0, rest_1.requestBody)()),
    (0, tslib_1.__metadata)("design:type", Function),
    (0, tslib_1.__metadata)("design:paramtypes", [Number, models_1.AuthClient]),
    (0, tslib_1.__metadata)("design:returntype", Promise)
], AuthClientController.prototype, "replaceById", null);
(0, tslib_1.__decorate)([
    (0, loopback4_authentication_1.authenticate)("bearer" /* BEARER */),
    (0, loopback4_authorization_1.authorize)({ permissions: ["NotAllowed" /* NotAllowed */] }),
    (0, rest_1.del)(`${baseUrl}/{id}`, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            '204': {
                description: 'AuthClient DELETE success',
            },
        },
    }),
    (0, tslib_1.__param)(0, rest_1.param.path.number('id')),
    (0, tslib_1.__metadata)("design:type", Function),
    (0, tslib_1.__metadata)("design:paramtypes", [Number]),
    (0, tslib_1.__metadata)("design:returntype", Promise)
], AuthClientController.prototype, "deleteById", null);
AuthClientController = (0, tslib_1.__decorate)([
    (0, tslib_1.__param)(0, (0, repository_1.repository)(repositories_1.AuthClientRepository)),
    (0, tslib_1.__metadata)("design:paramtypes", [repositories_1.AuthClientRepository])
], AuthClientController);
exports.AuthClientController = AuthClientController;
//# sourceMappingURL=auth-client.controller.js.map